==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/gui/admin_buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_buttons.lang.inc.php 2017-09-05
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_ACCOUNTING' => 'Adminrechte',
	'BUTTON_ADD' => 'Hinzufügen',
	'BUTTON_AFTERBUY_SEND' => 'Afterbuy - senden',
	'BUTTON_APPLY' => 'Anwenden',
	'BUTTON_ATTRIBUTES' => 'Attribute',
	'BUTTON_BACK' => 'Zurück',
	'BUTTON_BACKUP' => 'Backup erstellen',
	'BUTTON_BACKUP_IMAGES' => 'Bilder sichern',
	'BUTTON_CANCEL' => 'Abbrechen',
	'BUTTON_CLOSE' => 'Schließen',
	'BUTTON_CONFIRM' => 'Bestätigen',
	'BUTTON_COPY' => 'Kopieren',
	'BUTTON_COPY_LANGUAGE' => 'Sprache kopieren',
	'BUTTON_CREATE' => 'Erstellen',
	'BUTTON_CREATE_ACCOUNT' => 'Neuer Kunde',
	'BUTTON_DELETE' => 'Löschen',
	'BUTTON_DETAILS' => 'Details',
	'BUTTON_DOWNLOAD' => 'Herunterladen',
	'BUTTON_EDIT' => 'Bearbeiten',
	'BUTTON_EDIT_ADDRESS' => 'Kundendaten bearbeiten',
	'BUTTON_EDIT_ATTRIBUTES' => 'Attribute editieren',
	'BUTTON_EDIT_PRODUCTS' => 'Artikel bearbeiten',
	'BUTTON_EDIT_TOTALS' => 'Summen bearbeiten',
	'BUTTON_EMAIL' => 'E-Mail',
	'BUTTON_EXPORT' => 'Exportieren',
	'BUTTON_FILTER' => 'Filtern',
	'BUTTON_IMPORT' => 'Importieren',
	'BUTTON_INSERT' => 'Einfügen',
	'BUTTON_INVOICE' => 'Rechnung',
	'BUTTON_IPLOG' => 'IP-Log',
	'BUTTON_MARK_AS_READ' => 'Als gelesen markieren',
	'BUTTON_LOAD_MORE_LOGS' => 'Mehr Logs laden',
	'BUTTON_LOAD_ALL_LOGS' => 'Alle Logs laden',
	'BUTTON_MEDIAFINANZ_CREDITWORTHINESS' => 'Bonitätsübersicht',
	'BUTTON_MODULE_INSTALL' => 'Installieren',
	'BUTTON_MODULE_REMOVE' => 'Deinstallieren',
	'BUTTON_MOVE' => 'Verschieben',
	'BUTTON_NEW_BANNER' => 'Neuer Banner',
	'BUTTON_NEW_CATEGORIES' => 'Neue Kategorie',
	'BUTTON_NEW_CONTENT' => 'Neuer Content',
	'BUTTON_NEW_COUNTRY' => 'Neues Land',
	'BUTTON_NEW_CURRENCY' => 'Neue Währung',
	'BUTTON_NEW_LANGUAGE' => 'Sprache anlegen',
	'BUTTON_NEW_NEWSLETTER' => 'Neuer Newsletter',
	'BUTTON_NEW_ORDER' => 'Neue Bestellung',
	'BUTTON_NEW_PREFIX' => 'Neue',
	'BUTTON_NEW_PREFIX_2' => 'Neuer',
	'BUTTON_NEW_PRODUCTS' => 'Neuer Artikel',
	'BUTTON_NEW_PRODUCTS_CONTENT' => 'Neuer Artikel-Content',
	'BUTTON_NEW_TAX_CLASS' => 'Neue Steuerklasse',
	'BUTTON_NEW_TAX_RATE' => 'Neuer Steuersatz',
	'BUTTON_NEW_ZONE' => 'Neues Bundesland',
	'BUTTON_OPEN' => 'Öffnen',
	'BUTTON_ORDERS' => 'Bestellungen',
	'BUTTON_PACKINGSLIP' => 'Lieferschein',
	'BUTTON_PREVIEW' => 'Vorschau',
	'BUTTON_PRODUCT_OPTIONS' => 'Artikeloptionen',
	'BUTTON_PROPERTIES' => 'Eigenschaften',
	'BUTTON_RELEASE' => 'Einlösen',
	'BUTTON_REMOVE_CC_INFO' => 'Kreditkarten-Info löschen',
	'BUTTON_REPORT' => 'Report',
	'BUTTON_RESET' => 'Zurücksetzen',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Auf Standardeinstellung zurücksetzen',
	'BUTTON_RESTORE' => 'Wiederherstellen',
	'BUTTON_REVERSE_SELECTION' => 'Auswahl umkehren',
	'BUTTON_REVIEW_APPROVE' => 'OK',
	'BUTTON_SAVE' => 'Speichern',
	'BUTTON_SEARCH' => 'Suchen',
	'BUTTON_SEND' => 'Senden',
	'BUTTON_SEND_COUPON' => 'Gutschein senden',
	'BUTTON_SEND_EMAIL' => 'E-Mail senden',
	'BUTTON_SHOW' => 'Anzeigen',
	'BUTTON_SPECIAL' => 'Sonderangebot',
	'BUTTON_START' => 'Start',
	'BUTTON_STATUS' => 'Kundengruppe',
	'BUTTON_STATUS_OFF' => 'Status inaktiv',
	'BUTTON_STATUS_ON' => 'Status aktiv',
	'BUTTON_SWITCH_CATEGORIES' => 'Nur Kategorien',
	'BUTTON_SWITCH_EDITOR_HTML' => 'HTML',
	'BUTTON_SWITCH_EDITOR_TEXT' => 'Text',
	'BUTTON_SWITCH_PRODUCTS' => 'Nur Artikel',
	'BUTTON_TAKE' => 'Übernehmen',
	'BUTTON_UPDATE' => 'Aktualisieren',
	'BUTTON_UPLOAD' => 'Hochladen',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/gui/admin_buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_buttons.lang.inc.php 2021-11-03
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2021 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_ACCOUNTING' => 'Adminrechte',
	'BUTTON_ADD' => 'Hinzufügen',
	'BUTTON_AFTERBUY_SEND' => 'Afterbuy - senden',
	'BUTTON_APPLY' => 'Anwenden',
	'BUTTON_ATTRIBUTES' => 'Attribute',
	'BUTTON_BACK' => 'Zurück',
	'BUTTON_BACKUP' => 'Backup erstellen',
	'BUTTON_BACKUP_IMAGES' => 'Bilder sichern',
	'BUTTON_CANCEL' => 'Abbrechen',
	'BUTTON_CLOSE' => 'Schließen',
	'BUTTON_CONFIRM' => 'Bestätigen',
    'BUTTON_GO_TO_PRODUCT' => 'Produkt aufrufen',
	'BUTTON_COPY' => 'Kopieren',
	'BUTTON_COPY_LANGUAGE' => 'Sprache kopieren',
	'BUTTON_CREATE' => 'Erstellen',
	'BUTTON_CREATE_ACCOUNT' => 'Neuer Kunde',
	'BUTTON_DELETE' => 'Löschen',
	'BUTTON_DETAILS' => 'Details',
	'BUTTON_DOWNLOAD' => 'Herunterladen',
	'BUTTON_EDIT' => 'Bearbeiten',
	'BUTTON_EDIT_ADDRESS' => 'Kundendaten bearbeiten',
	'BUTTON_EDIT_ATTRIBUTES' => 'Attribute editieren',
	'BUTTON_EDIT_PRODUCTS' => 'Artikel bearbeiten',
	'BUTTON_EDIT_TOTALS' => 'Summen bearbeiten',
	'BUTTON_EMAIL' => 'E-Mail',
	'BUTTON_EXPORT' => 'Exportieren',
	'BUTTON_FILTER' => 'Filtern',
	'BUTTON_IMPORT' => 'Importieren',
	'BUTTON_INSERT' => 'Einfügen',
	'BUTTON_INVOICE' => 'Rechnung',
	'BUTTON_IPLOG' => 'IP-Log',
	'BUTTON_MARK_AS_READ' => 'Als gelesen markieren',
	'BUTTON_LOAD_MORE_LOGS' => 'Mehr Logs laden',
	'BUTTON_LOAD_ALL_LOGS' => 'Alle Logs laden',
	'BUTTON_MEDIAFINANZ_CREDITWORTHINESS' => 'Bonitätsübersicht',
	'BUTTON_MODULE_INSTALL' => 'Installieren',
	'BUTTON_MODULE_REMOVE' => 'Deinstallieren',
	'BUTTON_MOVE' => 'Verschieben',
	'BUTTON_NEW_BANNER' => 'Neues Banner',
	'BUTTON_NEW_CATEGORIES' => 'Neue Kategorie',
	'BUTTON_NEW_CONTENT' => 'Neuer Content',
	'BUTTON_NEW_COUNTRY' => 'Neues Land',
	'BUTTON_NEW_CURRENCY' => 'Neue Währung',
	'BUTTON_NEW_LANGUAGE' => 'Sprache anlegen',
	'BUTTON_NEW_NEWSLETTER' => 'Neuer Newsletter',
	'BUTTON_NEW_ORDER' => 'Neue Bestellung',
	'BUTTON_NEW_PREFIX' => 'Neue',
	'BUTTON_NEW_PREFIX_2' => 'Neuer',
	'BUTTON_NEW_PRODUCTS' => 'Neuer Artikel',
	'BUTTON_NEW_PRODUCTS_CONTENT' => 'Neuer Artikel-Content',
	'BUTTON_NEW_TAX_CLASS' => 'Neue Steuerklasse',
	'BUTTON_NEW_TAX_RATE' => 'Neuer Steuersatz',
	'BUTTON_NEW_ZONE' => 'Neues Bundesland',
	'BUTTON_OPEN' => 'Öffnen',
	'BUTTON_ORDERS' => 'Bestellungen',
	'BUTTON_PACKINGSLIP' => 'Lieferschein',
	'BUTTON_PREVIEW' => 'Vorschau',
	'BUTTON_PRODUCT_OPTIONS' => 'Zusatzoptionen',
	'BUTTON_PROPERTIES' => 'Varianten',
	'BUTTON_RELEASE' => 'Einlösen',
	'BUTTON_REMOVE_CC_INFO' => 'Kreditkarten-Info löschen',
	'BUTTON_REPORT' => 'Melden',
	'BUTTON_RESET' => 'Zurücksetzen',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Auf Standardeinstellungen zurücksetzen',
	'BUTTON_RESTORE' => 'Wiederherstellen',
	'BUTTON_REVERSE_SELECTION' => 'Auswahl umkehren',
	'BUTTON_REVIEW_APPROVE' => 'OK',
	'BUTTON_SAVE' => 'Speichern',
	'BUTTON_SEARCH' => 'Suchen',
	'BUTTON_SEND' => 'Senden',
	'BUTTON_SEND_COUPON' => 'Gutschein senden',
	'BUTTON_SEND_EMAIL' => 'E-Mail senden',
	'BUTTON_SHOW' => 'Anzeigen',
	'BUTTON_SPECIAL' => 'Sonderangebot',
	'BUTTON_START' => 'Start',
	'BUTTON_STATUS' => 'Kundengruppe',
	'BUTTON_STATUS_OFF' => 'Status inaktiv',
	'BUTTON_STATUS_ON' => 'Status aktiv',
	'BUTTON_SWITCH_CATEGORIES' => 'Nur Kategorien',
	'BUTTON_SWITCH_EDITOR_HTML' => 'HTML',
	'BUTTON_SWITCH_EDITOR_TEXT' => 'Text',
	'BUTTON_SWITCH_PRODUCTS' => 'Nur Artikel',
	'BUTTON_TAKE' => 'Übernehmen',
	'BUTTON_UPDATE' => 'Aktualisieren',
	'BUTTON_UPLOAD' => 'Hochladen',
    'BUTTON_PRODUCT_DOWNLOADS' => 'Downloads',
);
